==> piwik-2.0.3.tgz: piwik/plugins/MobileMessaging/GSMCharset.php <==
<?php
/**
 * Piwik - Open source web analytics
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 * @category Piwik_Plugins
 * @package MobileMessaging
 */

namespace Piwik\Plugins\MobileMessaging;

/**
 * GSM 03.38 Charset
 *
 * @package MobileMessaging
 */
class GSMCharset
{
    public static $GSMCharset = array(

        // Standard GSM Characters, weight = 1
        '@'  => 1,
        '£'  => 1,
        '$'  => 1,
        '¥'  => 1,
        'è'  => 1,
        'é'  => 1,
        'ù'  => 1,
        'ì'  => 1,
        'ò'  => 1,
        'Ç'  => 1,
        'Ø'  => 1,
        'ø'  => 1,
        'Å'  => 1,
        'å'  => 1,
        '∆'  => 1,
        '_'  => 1,
        'Φ'  => 1,
        'Γ'  => 1,
        'Λ'  => 1,
        'Ω'  => 1,
        'Π'  => 1,
        'Ψ'  => 1,
        'Σ'  => 1,
        'Θ'  => 1,
        'Ξ'  => 1,
        'Æ'  => 1,
        'æ'  => 1,
        'ß'  => 1,
        'É'  => 1,
        ' '  => 1,
        '!'  => 1,
        '"'  => 1,
        '#'  => 1,
        '¤'  => 1,
        '%'  => 1,
        '&'  => 1,
        '\'' => 1,
        '('  => 1,
        ')'  => 1,
        '*'  => 1,
        '+'  => 1,
        ','  => 1,
        '-'  => 1,
        '.'  => 1,
        '/'  => 1,
        '0'  => 1,
        '1'  => 1,
        '2'  => 1,
        '3'  => 1,
        '4'  => 1,
        '5'  => 1,
        '6'  => 1,
        '7'  => 1,
        '8'  => 1,
        '9'  => 1,
        ':'  => 1,
        ';'  => 1,
        '<'  => 1,
        '='  => 1,
        '>'  => 1,
        '?'  => 1,
        '¡'  => 1,
        'A'  => 1,
        'B'  => 1,
        'C'  => 1,
        'D'  => 1,
        'E'  => 1,
        'F'  => 1,
        'G'  => 1,
        'H'  => 1,
        'I'  => 1,
        'J'  => 1,
        'K'  => 1,
        'L'  => 1,
        'M'  => 1,
        'N'  => 1,
        'O'  => 1,
        'P'  => 1,
        'Q'  => 1,
        'R'  => 1,
        'S'  => 1,
        'T'  => 1,
        'U'  => 1,
        'V'  => 1,
        'W'  => 1,
        'X'  => 1,
        'Y'  => 1,
        'Z'  => 1,
        'Ä'  => 1,
        'Ö'  => 1,
        'Ñ'  => 1,
        'Ü'  => 1,
        '§'  => 1,
        '¿'  => 1,
        'a'  => 1,
        'b'  => 1,
        'c'  => 1,
        'd'  => 1,
        'e'  => 1,
        'f'  => 1,
        'g'  => 1,
        'h'  => 1,
        'i'  => 1,
        'j'  => 1,
        'k'  => 1,
        'l'  => 1,
        'm'  => 1,
        'n'  => 1,
        'o'  => 1,
        'p'  => 1,
        'q'  => 1,
        'r'  => 1,
        's'  => 1,
        't'  => 1,
        'u'  => 1,
        'v'  => 1,
        'w'  => 1,
        'x'  => 1,
        'y'  => 1,
        'z'  => 1,
        'ä'  => 1,
        'ö'  => 1,
        'ñ'  => 1,
        'ü'  => 1,
        'à'  => 1,

        // Extended GSM Characters, weight = 2
        '^'  => 2,
        '{'  => 2,
        '}'  => 2,
        '\\' => 2,
        '['  => 2,
        '~'  => 2,
        ']'  => 2,
        '|'  => 2,
        '€'  => 2,
    );
}

==> piwik-2.14.0.tgz: piwik/plugins/MobileMessaging/GSMCharset.php <==
<?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 */

namespace Piwik\Plugins\MobileMessaging;

/**
 * GSM 03.38 Charset
 *
 */
class GSMCharset
{
    public static $GSMCharset = array(

        // Standard GSM Characters, weight = 1
        '@'  => 1,
        '£'  => 1,
        '$'  => 1,
        '¥'  => 1,
        'è'  => 1,
        'é'  => 1,
        'ù'  => 1,
        'ì'  => 1,
        'ò'  => 1,
        'Ç'  => 1,
        'Ø'  => 1,
        'ø'  => 1,
        'Å'  => 1,
        'å'  => 1,
        '∆'  => 1,
        '_'  => 1,
        'Φ'  => 1,
        'Γ'  => 1,
        'Λ'  => 1,
        'Ω'  => 1,
        'Π'  => 1,
        'Ψ'  => 1,
        'Σ'  => 1,
        'Θ'  => 1,
        'Ξ'  => 1,
        'Æ'  => 1,
        'æ'  => 1,
        'ß'  => 1,
        'É'  => 1,
        ' '  => 1,
        '!'  => 1,
        '"'  => 1,
        '#'  => 1,
        '¤'  => 1,
        '%'  => 1,
        '&'  => 1,
        '\'' => 1,
        '('  => 1,
        ')'  => 1,
        '*'  => 1,
        '+'  => 1,
        ','  => 1,
        '-'  => 1,
        '.'  => 1,
        '/'  => 1,
        '0'  => 1,
        '1'  => 1,
        '2'  => 1,
        '3'  => 1,
        '4'  => 1,
        '5'  => 1,
        '6'  => 1,
        '7'  => 1,
        '8'  => 1,
        '9'  => 1,
        ':'  => 1,
        ';'  => 1,
        '<'  => 1,
        '='  => 1,
        '>'  => 1,
        '?'  => 1,
        '¡'  => 1,
        'A'  => 1,
        'B'  => 1,
        'C'  => 1,
        'D'  => 1,
        'E'  => 1,
        'F'  => 1,
        'G'  => 1,
        'H'  => 1,
        'I'  => 1,
        'J'  => 1,
        'K'  => 1,
        'L'  => 1,
        'M'  => 1,
        'N'  => 1,
        'O'  => 1,
        'P'  => 1,
        'Q'  => 1,
        'R'  => 1,
        'S'  => 1,
        'T'  => 1,
        'U'  => 1,
        'V'  => 1,
        'W'  => 1,
        'X'  => 1,
        'Y'  => 1,
        'Z'  => 1,
        'Ä'  => 1,
        'Ö'  => 1,
        'Ñ'  => 1,
        'Ü'  => 1,
        '§'  => 1,
        '¿'  => 1,
        'a'  => 1,
        'b'  => 1,
        'c'  => 1,
        'd'  => 1,
        'e'  => 1,
        'f'  => 1,
        'g'  => 1,
        'h'  => 1,
        'i'  => 1,
        'j'  => 1,
        'k'  => 1,
        'l'  => 1,
        'm'  => 1,
        'n'  => 1,
        'o'  => 1,
        'p'  => 1,
        'q'  => 1,
        'r'  => 1,
        's'  => 1,
        't'  => 1,
        'u'  => 1,
        'v'  => 1,
        'w'  => 1,
        'x'  => 1,
        'y'  => 1,
        'z'  => 1,
        'ä'  => 1,
        'ö'  => 1,
        'ñ'  => 1,
        'ü'  => 1,
        'à'  => 1,

        // Extended GSM Characters, weight = 2
        '^'  => 2,
        '{'  => 2,
        '}'  => 2,
        '\\' => 2,
        '['  => 2,
        '~'  => 2,
        ']'  => 2,
        '|'  => 2,
        '€'  => 2,
    );
}
